import { memo } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import AtomSlider from '@s-ui/react-atom-slider';
import MoleculeField from '@s-ui/react-molecule-field';
import { createComponentMemo } from '../prop-types/index.js';
import { jsx as _jsx } from "react/jsx-runtime";

var PickerSlider = function PickerSlider(_ref) {
  var slider = _ref.slider,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      errors = _ref.errors,
      alerts = _ref.alerts;
  var id = slider.id,
      datalist = slider.datalist;
  var className = cx('sui-FormBuilder-field', 'sui-FormBuilder-PickerSlider', "sui-FormBuilder-" + id);
  var min = 0;
  var max = datalist.length - 1;
  var value = datalist.findIndex(function (data) {
    return data.value === slider.value;
  });
  var errorMessages = errors[id];
  var alertMessages = alerts[id];

  var formatter = function formatter(index) {
    return datalist[index].text;
  };

  var handleChange = function handleChange(event, _ref2) {
    var index = _ref2.value;
    onChange(id, datalist[index].value);
  };

  var handleBlur = function handleBlur() {
    return onBlur(id, {
      type: slider.type,
      display: slider.display,
      label: slider.label
    });
  };

  var handleFocus = function handleFocus() {
    return onFocus(id, {
      type: slider.type,
      display: slider.display,
      label: slider.label
    });
  };

  if (slider.hidden) {
    return null;
  }

  return /*#__PURE__*/_jsx("div", {
    className: className,
    children: /*#__PURE__*/_jsx(MoleculeField, {
      name: id,
      label: slider.label,
      helpText: slider.help,
      errorText: errorMessages && errorMessages.join('\n'),
      alertText: alertMessages && alertMessages.join('\n'),
      onChange: handleChange,
      onBlur: handleBlur,
      onFocus: handleFocus,
      children: /*#__PURE__*/_jsx(AtomSlider, {
        id: id,
        value: value,
        min: min,
        max: max,
        valueLabelFormatter: formatter,
        valueLabel: true,
        hideTooltip: true,
        marks: [formatter(min), formatter(max)]
      })
    })
  });
};

PickerSlider.displayName = 'PickerSlider';
export default /*#__PURE__*/memo(PickerSlider, createComponentMemo('slider'));